﻿using Grasshopper.Kernel;
using Rhino.Geometry;
using System;

namespace Ehsan
{
    public class EhsanComponent : GH_Component
    {
        public EhsanComponent() : base("Ehsan", "Nickname", "Description", "Category", "Subcategory") { }
        protected override void RegisterInputParams(GH_InputParamManager pManager)
        {
            pManager.AddBrepParameter("Brep", "B", "", GH_ParamAccess.item);
            pManager.AddNumberParameter("Distance", "D", "", GH_ParamAccess.item);
            pManager.AddBooleanParameter("Soild", "S", "", GH_ParamAccess.item, false);
            pManager.AddBooleanParameter("BothSides", "B", "", GH_ParamAccess.item, false);
            pManager.AddBooleanParameter("Round", "R", "", GH_ParamAccess.item, false);
            pManager.AddBooleanParameter("MergeFaces", "M", "", GH_ParamAccess.item, false);
        }
        protected override void RegisterOutputParams(GH_OutputParamManager pManager)
        {
            pManager.AddBrepParameter("Brep", "B", "", GH_ParamAccess.item);
        }

        protected override void SolveInstance(IGH_DataAccess da)
        {
            Brep p = null;
            var d = 0.0;
            var s = false;
            var b = false;
            var r = false;
            var m = false;
            da.GetData(0, ref p);
            da.GetData(1, ref d);
            da.GetData(2, ref s);
            da.GetData(3, ref b);
            da.GetData(4, ref r);
            da.GetData(5, ref m);
            Brep[] offset;
            p.Faces.SplitKinkyFaces(0.1, true);
            if (b)
            {
                offset = Brep.CreateOffsetBrep(p, -d, false, r, DocumentTolerance(), out _, out _);
                offset = Brep.CreateOffsetBrep(offset[0], d * 2, true, r, DocumentTolerance(), out _, out _);
            }
            else
                offset = Brep.CreateOffsetBrep(p, d, s, r, DocumentTolerance(), out _, out _);

            if (m)
                offset[0].MergeCoplanarFaces(DocumentTolerance());
            da.SetData(0, offset[0]);
        }
        protected override System.Drawing.Bitmap Icon => null;
        public override Guid ComponentGuid => new Guid("a0eaf272-46fb-4adb-8b8e-32dbadf9c84c");
    }
}
